@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 142 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 145 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 147 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -158,7 +158,7 @@ pref("gfx.downloadable_fonts.enabled", true);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 163 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 163 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -171,7 +171,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 179 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 179 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -519,9 +519,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 527 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 527 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 529 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 529 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -566,7 +566,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 576 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 576 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -718,6 +718,8 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
 // sa, Saudi Arabia, .<al-Saudiah>
 pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
 // ru, Russian Federation, .<RF>
@@ -811,7 +813,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 826 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 828 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -830,9 +832,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 846 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 848 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 853 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 855 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1194,15 +1196,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1593 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1595 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2010 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2012 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2211 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2213 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2305 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2307 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2308 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2310 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1470,15 +1472,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2578 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2580 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2646 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2648 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2672 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2674 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2692 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2694 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2700 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2702 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1502,7 +1504,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2729 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2731 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
